Crate kcr_parameters_kubeblocks_io

Crate kcr_parameters_kubeblocks_io 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the parameters.kubeblocks.io group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

parameters.kubeblocks.io/v1alpha1

  • ComponentParameter
  • ParamConfigRenderer
  • Parameter
  • ParametersDefinition

Modules

v1alpha1